==> activity-center-api-3.6.26-20250907.040043-5-sources.jar: cn/com/duiba/activity/center/api/remoteservice/wanda/RemoteWandaGroggeryService.java <==
package cn.com.duiba.activity.center.api.remoteservice.wanda;

import cn.com.duiba.activity.center.api.dto.wanda.GroggeryDto;
import cn.com.duiba.activity.center.api.params.wanda.QueryGroggeryParam;
import cn.com.duiba.activity.center.api.tool.Page;
import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import java.util.List;

/**
 * 万达酒店远程服务接口
 * @author zhengzhihao
 */
@AdvancedFeignClient
public interface RemoteWandaGroggeryService {

    /**
     * 根据查询参数分页查询酒店列表
     * @return 酒店列表查询结果
     */
    Page<GroggeryDto> listGroggeryByNameAndCode(QueryGroggeryParam param);

    /**
     * 根据酒店code查询到酒店
     */
    GroggeryDto getGroggeryByCode(String code);

    /**
     * 批量更新酒店分佣比例
     * @param groggeryCodes 酒店编码列表
     * @param disRate 分佣比例
     * @return 更新结果
     */
    Boolean batchUpdateGroggeryDisRate(List<String> groggeryCodes, String disRate) throws BizException;

    /**
     * 递增酒店分销金额和商品数量
     * @param groggeryCode 酒店编码
     * @param amount 增加的金额(分)
     * @param quantity 增加的商品数量
     * @return 更新结果
     */
    Boolean incrementGroggeryDisAmount(String groggeryCode, Long amount, Long quantity) throws BizException;

    /**
     * 递增员工分销金额
     * @param groggeryCode 酒店编码
     * @param amount 增加的金额(分)
     * @return 更新结果
     */
    Boolean incrementEmployeeDisAmount(String groggeryCode, Long amount) throws BizException;

    /**
     * 批量创建酒店
     * @param groggeryDtoList 酒店信息列表
     * @return 创建结果
     */
    Boolean batchCreateGroggery(List<GroggeryDto> groggeryDtoList) throws BizException;

    /**
     * 批量更新酒店名称
     * @param groggeryDtoList 需要更新的酒店信息列表(包含code和name)
     * @return 更新结果
     */
    Boolean batchUpdateGroggeryName(List<GroggeryDto> groggeryDtoList) throws BizException;
}

==> activity-center-api-3.6.29-20251009.142021-3-sources.jar: cn/com/duiba/activity/center/api/remoteservice/wanda/RemoteWandaGroggeryService.java <==
package cn.com.duiba.activity.center.api.remoteservice.wanda;

import cn.com.duiba.activity.center.api.dto.wanda.GroggeryDto;
import cn.com.duiba.activity.center.api.params.wanda.QueryGroggeryParam;
import cn.com.duiba.activity.center.api.tool.Page;
import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import java.util.List;

/**
 * 万达酒店远程服务接口
 * @author zhengzhihao
 */
@AdvancedFeignClient
public interface RemoteWandaGroggeryService {

    /**
     * 根据查询参数分页查询酒店列表
     * @return 酒店列表查询结果
     */
    Page<GroggeryDto> listGroggeryByNameAndCode(QueryGroggeryParam param);

    /**
     * 根据酒店code查询到酒店
     */
    GroggeryDto getGroggeryByCode(String code);

    /**
     * 批量更新酒店分佣比例
     * @param groggeryCodes 酒店编码列表
     * @param disRate 分佣比例
     * @return 更新结果
     */
    Boolean batchUpdateGroggeryDisRate(List<String> groggeryCodes, String disRate) throws BizException;

    /**
     * 递增酒店分销金额和商品数量
     * @param groggeryCode 酒店编码
     * @param amount 增加的金额(分)
     * @param quantity 增加的商品数量
     * @return 更新结果
     */
    Boolean incrementGroggeryDisAmount(String groggeryCode, Long amount, Long quantity) throws BizException;

    /**
     * 递增员工分销金额
     * @param groggeryCode 酒店编码
     * @param amount 增加的金额(分)
     * @return 更新结果
     */
    Boolean incrementEmployeeDisAmount(String groggeryCode, Long amount) throws BizException;

    /**
     * 批量创建酒店
     * @param groggeryDtoList 酒店信息列表
     * @return 创建结果
     */
    Boolean batchCreateGroggery(List<GroggeryDto> groggeryDtoList) throws BizException;

    /**
     * 批量更新酒店名称
     * @param groggeryDtoList 需要更新的酒店信息列表(包含code和name)
     * @return 更新结果
     */
    Boolean batchUpdateGroggeryName(List<GroggeryDto> groggeryDtoList) throws BizException;

    /**
     * 修改酒店密码
     * @param groggeryCode 酒店编码
     * @param password 新密码
     * @return 修改结果
     */
    Boolean updateGroggeryPassword(String groggeryCode, String password) throws BizException;
}
